@@ -1,7 +1,8 @@
 # Add the human gestational PBTK model to the list of models:
 # 
-# Kapraun et al. "Evaluation of a Rapid, Multi-Chemical Human Gestational Dose Model"
-# in preparation
+# Kapraun, Dustin F., et al. 
+# "Evaluation of a rapid, generic human gestational dose model." 
+# Reproductive Toxicology 113 (2022): 172-188.
 
 
 #Analytic expression for steady-state plasma concentration.
@@ -66,7 +67,7 @@ model.list[["fetal_pbtk"]]$param.names <- c(
   "Clint",
   "Clint.dist",
   "Clmetabolismc",                
-  "Fgutabs",      
+  "Fabsgut",      
   "Fhep.assay.correction",
   "Fraction_unbound_plasma_fetus",
   "Funbound.plasma",              
@@ -543,7 +544,9 @@ model.list[["fetal_pbtk"]]$derivative.output.names <- c(
   "Cfbrain",
   "Afplasma",
   "Cfplasma",
-  "Rfblood2plasma")
+  "Rfblood2plasma",
+  "Qcardiac",
+  "Qthyroid")
 
 #Which variables to track by default (should be able to build this from
 #state vars and outputs):
@@ -574,7 +577,9 @@ model.list[["fetal_pbtk"]]$default.monitor.vars <- c(
   "Cfkidney",
   "Cfbrain",
   "Cfplasma",
-  "Rfblood2plasma")
+  "Rfblood2plasma",
+  "Qcardiac",
+  "Qthyroid")
 
 # Allowable units assigned to dosing input:
 model.list[["fetal_pbtk"]]$allowed.units.input <- list(
@@ -584,9 +589,9 @@ model.list[["fetal_pbtk"]]$allowed.units.input <- list(
 # Allowable units assigned to entries in the output columns of the ode system
 model.list[["fetal_pbtk"]]$allowed.units.output <- list(
   "oral" = c('uM','mg/L','umol','mg','uM*days',
-             'mg/L*days',"unitless"),
+             'mg/L*days',"unitless","L/d"),
   "iv" = c('uM','mg/L','umol','mg','uM*days',
-             'mg/L*days',"unitless"))
+             'mg/L*days',"unitless","L/d"))
 
 ## These parameters specify the exposure scenario simulated by the model:
 model.list[["fetal_pbtk"]]$routes <- list(
@@ -686,8 +691,13 @@ model.list[["fetal_pbtk"]]$compartment.units <- c(
   "AUC" = "uM*days",
   "fAUC" = "uM*days",
   "Rblood2plasma" = "unitless",
-  "Rfblood2plasma" = "unitless")
+  "Rfblood2plasma" = "unitless",
+  "Qcardiac" = "L/d",
+  "Qthyroid" = "L/d")
 
+# Compartment state of matter, needed for proper unit conversion, if all
+# comaprtments of the same only include one state and set it to "all":
+model.list[["fetal_pbtk"]]$compartment.state <- list(liquid="all")
        
 #Parameters needed to make a prediction (this is used by get_cheminfo):
 model.list[["fetal_pbtk"]]$required.params <- c(
