@@ -1,4 +1,8 @@
-#R CMD BATCH --no-timing --no-restore --no-save 3comp_test.R 3comp_test.Rout
+# R CMD BATCH --no-timing --no-restore --no-save 3comp_test.R 3comp_test.Rout
+
+# Get rid of anything in the workspace:
+rm(list=ls()) 
+
 library(httk)
 
 calc_analytic_css(chem.name="bisphenol a",model="3compartment")
@@ -47,52 +51,7 @@ head(initial_nondefault_dose)
 initial_nondefault_dose_intestine = out_nondefault_dosing[2,"Aintestine"]
 head(initial_nondefault_dose_intestine)
 
-#parameterize_3comp(chem.name="Aminopterin")[sort(names(parameterize_3comp(chem.name="Aminopterin")))]
-
-script.args <- commandArgs(TRUE)
-if (length(script.args) > 0) 
-{
-  if (any(script.args=="mctest"))
-  {
-    set.seed(12345)
-    calc_mc_css(chem.name="bisphenol a",model="3compartment")
-    set.seed(12345)
-    calc_mc_css(chem.cas="80-05-7",model="3compartment")
-    set.seed(12345)
-    calc_mc_css(parameters=parameterize_3comp(chem.cas="80-05-7"),model="3compartment")
-  }                                            
-  if (any(script.args=="wetmoretest"))
-  {
-    wetmore.chems <- subset(chem.physical_and_invitro.data,
-      regexpr("Wetmore",Human.Clint.Reference)!=-1 &
-      regexpr("Wetmore",Human.Funbound.plasma.Reference)!=-1)
-    Css.table <- data.frame()
-    for (this.cas in sort(get_lit_cheminfo()))
-      if (this.cas %in% get_cheminfo(model="pbtk") &
-        this.cas %in% wetmore.chems$CAS)
-      {
-        Css.table[this.cas,"Css.lit"] <- get_lit_css(chem.cas=this.cas,
-          output.units="uM",
-          which.quantile=0.5)
-        Css.table[this.cas,"Css.calc"] <- calc_analytic_css(chem.cas=this.cas,
-          model="3compartment")
-      }                                                                          
-    cat(lm(log(Css.lit)~log(Css.calc),data=Css.table)$coefficients)
-      
-    #library(ggplot2)
-    #test.fig <- ggplot(Css.table,aes(x=Css.calc,y=Css.lit)) +
-    #         geom_point(size=3)+
-    #   scale_y_log10()+
-    #   scale_x_log10()+
-    #  ylab(expression(paste(C[aa]," Literature (uM)"))) +
-    #  xlab(expression(paste(C[aa]," 3compartment model (uM)"))) +
-    #  geom_abline(intercept = 0, slope = 1,linetype="dashed", colour="Blue") 
-    #
-    #dev.new()
-    #print(test.fig)
-  }
-}
-
-
+p <- parameterize_3comp(chem.name="Aminopterin")[sort(names(parameterize_3comp(chem.name="Aminopterin")))]
+for (this.param in sort(tolower(names(p)))) cat(paste(this.param,": ",p[[this.param]],"\n"))
 
 quit("no")
\ No newline at end of file
